
'''
This file is automatically generated; Do not edit it. :)
'''
VERSION_INFO = {
    'final': True,
    'version': '1.18.5',
    'branch_nick': 'patch-0-1_18_5_preparation',
    'revision_id': 'd16baa80c39ee3870ffb65d16fa5814e47360d9a',
    'revno': 7299
}
